import React, { useEffect, useState } from 'react'
import { Form, Modal, Button, Input, InputNumber, Select, Radio, PageHeader } from 'antd'
import { fetch, apis } from '@/utils/request'
import MiniAppMedia from './components/MiniAppMedia'

const formItemLayout = {
  labelCol: {
    xs: { span: 24 },
    sm: { span: 6 },
  },
  wrapperCol: {
    xs: { span: 24 },
    sm: { span: 12 },
  },
}

const tailFormItemLayout = {
  wrapperCol: {
    xs: {
      span: 24,
      offset: 0,
    },
    sm: {
      span: 16,
      offset: 6,
    },
  },
}

const mpDetail = fetch(apis.mp.detail)

export default Form.create()(props => {
  const [detailData, setDetailData] = useState({})

  const handleMiniAppChange = vals => {
    setDetailData({
      ...detailData,
      miniappMedia: vals.mediaId,
      miniappUrl: vals.url
    })
  }

  useEffect(() => {
    mpDetail().then(res => {
      setDetailData(res)
      props.form.setFieldsValue(res)
    })
  }, [])

  return (
    <div>
      <PageHeader title="公众号设置" backIcon={false} />
      <Form {...formItemLayout}>
        {/* <Form.Item label="名称">
          {
            props.form.getFieldDecorator('name')(<Input placeholder="请填写名称" readOnly />)
          }
        </Form.Item> */}
        <Form.Item label="APPID">
          {
            props.form.getFieldDecorator('appid')(<Input placeholder="请填写 APPID" readOnly />)
          }
        </Form.Item>
        <Form.Item label="SECRET">
          {
            props.form.getFieldDecorator('secret')(<Input placeholder="请填写 SECRET" readOnly />)
          }
        </Form.Item>
        <Form.Item label="TOKEN">
          {
            props.form.getFieldDecorator('token')(<Input placeholder="请填写 TOKEN" readOnly />)
          }
        </Form.Item>
        <Form.Item label="AES_KEY">
          {
            props.form.getFieldDecorator('aesKey')(<Input placeholder="请填写 AES_KEY" readOnly />)
          }
        </Form.Item>
        <Form.Item label="小程序封面" help="仅支持JPG图片,建议大小为520*416">
          <div>
            {detailData.miniappMedia && <span style={{display: 'inline-block', marginRight: '24px'}}>{detailData.miniappMedia}</span>}
            <MiniAppMedia onChange={handleMiniAppChange} value={detailData.miniapp_url} />
          </div>
        </Form.Item>
      </Form>
    </div>
  )
})
